@@ -1,7 +1,7 @@
 package Org::To::Base;
 
 our $DATE = '2016-12-24'; # DATE
-our $VERSION = '0.20'; # VERSION
+our $VERSION = '0.21'; # VERSION
 
 use 5.010001;
 use Log::Any::IfLOG '$log';
@@ -72,8 +72,14 @@ sub export_elements {
     my $res = [];
   ELEM:
     for my $elem (@elems) {
-        require String::Escape;
+        if ($self->can("before_export_element")) {
+            $self->before_export_element(
+                hook => 'before_export_element',
+                elem => $elem,
+            );
+        }
         if ($log->is_trace) {
+            require String::Escape;
             $log->tracef("exporting element %s (%s) ...", ref($elem),
                          String::Escape::elide(
                              String::Escape::printable($elem->as_string), 30));
@@ -125,6 +131,13 @@ sub export_elements {
             push @$res, $self->export_elements(@{$elem->children})
                 if $elem->children;
         }
+
+        if ($self->can("after_export_element")) {
+            $self->after_export_element(
+                hook => 'after_export_element',
+                elem => $elem,
+            );
+        }
     }
 
     join "", @$res;
@@ -145,7 +158,7 @@ Org::To::Base - Base class for Org exporters
 
 =head1 VERSION
 
-This document describes version 0.20 of Org::To::Base (from Perl distribution Org-To-HTML), released on 2016-12-24.
+This document describes version 0.21 of Org::To::Base (from Perl distribution Org-To-HTML), released on 2016-12-24.
 
 =head1 SYNOPSIS
 
@@ -189,8 +202,26 @@ Export Org.
 =head2 $exp->export_elements(@elems) => STR
 
 Export Org element objects and with the children, recursively. Will call various
-export_*() methods according to element class. Should return a string which is
-the exported document.
+C<export_*()> methods according to element class. Should return a string which
+is the exported document.
+
+Several hooks are recognized and will be invoked if defined:
+
+=over
+
+=item * before_export_element
+
+Will be called before calling each C<export_*()>. Will be passed hash argument
+C<%hash> containing these keys: C<hook> (hook name, in this case
+C<before_export_element>), C<elem> (the element object).
+
+=item * after_export_element
+
+Will be called after calling each C<export_*()>. Will be passed hash argument
+C<%hash> containing these keys: C<hook> (hook name, in this case
+C<after_export_element>), C<elem> (the element object).
+
+=back
 
 =head1 HOMEPAGE
 
@@ -198,7 +229,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Org-To-HTM
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Org-To-HTML>.
+Source repository is at L<https://github.com/perlancar/perl-Org-To-HTML>.
 
 =head1 BUGS
 
