@@ -1,7 +1,7 @@
 package Org::To::HTML;
 
 our $DATE = '2016-12-24'; # DATE
-our $VERSION = '0.20'; # VERSION
+our $VERSION = '0.21'; # VERSION
 
 use 5.010;
 use Log::Any::IfLOG '$log';
@@ -134,6 +134,8 @@ sub org_to_html {
 sub export_document {
     my ($self, $doc) = @_;
 
+    $self->{_prev_elem_is_inline} = 0;
+
     my $html = [];
     unless ($self->naked) {
         push @$html, "<HTML>\n";
@@ -164,6 +166,14 @@ sub export_document {
     join "", @$html;
 }
 
+sub before_export_element {
+    my $self = shift;
+    my %args = @_;
+
+    $self->{_prev_elem_is_inline} =
+        $args{elem}->can("is_inline") && $args{elem}->is_inline ? 1:0;
+}
+
 sub export_block {
     my ($self, $elem) = @_;
     # currently all assumed to be <PRE>
@@ -338,7 +348,10 @@ sub export_text {
 
     push @$html, "<$tag>" if $tag;
     my $text = encode_entities($elem->text);
-    $text =~ s/\R\R/\n\n<p>/g;
+    $text =~ s/\R\R+/\n\n<p>/g;
+    if ($self->{_prev_elem_is_inline}) {
+        $text =~ s/\A\R/ /;
+    }
     $text =~ s/(?<=.)\R/ /g;
     push @$html, $text;
     push @$html, $self->export_elements(@{$elem->children}) if $elem->children;
@@ -397,7 +410,7 @@ Org::To::HTML - Export Org document to HTML
 
 =head1 VERSION
 
-This document describes version 0.20 of Org::To::HTML (from Perl distribution Org-To-HTML), released on 2016-12-24.
+This document describes version 0.21 of Org::To::HTML (from Perl distribution Org-To-HTML), released on 2016-12-24.
 
 =head1 SYNOPSIS
 
@@ -512,7 +525,7 @@ that contains extra information.
 
 Return value:  (any)
 
-=for Pod::Coverage ^(export_.+)$
+=for Pod::Coverage ^(export_.+|before_.+|after_.+)$
 
 =head1 ATTRIBUTES
 
@@ -538,7 +551,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Org-To-HTM
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Org-To-HTML>.
+Source repository is at L<https://github.com/perlancar/perl-Org-To-HTML>.
 
 =head1 BUGS
 
